@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005-2021 Jens Vagelpohl and Contributors. All Rights Reserved.
+# Copyright (c) 2005-2023 Jens Vagelpohl and Contributors. All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -24,13 +24,15 @@ try:
     from Products.GenericSetup.tests.common import DummyImportContext
 
     def test_suite():
+        loader = unittest.defaultTestLoader
         return unittest.TestSuite((
-            unittest.makeSuite(LDAPMultiPluginXMLAdapterTests),
-            unittest.makeSuite(ActiveDirectoryMultiPluginXMLAdapterTests),
-            unittest.makeSuite(LDAPMultiPluginExportTests),
-            unittest.makeSuite(ADMultiPluginExportTests),
-            unittest.makeSuite(LDAPMultiPluginImportTests),
-            unittest.makeSuite(ADMultiPluginImportTests),
+            loader.loadTestsFromTestCase(LDAPMultiPluginXMLAdapterTests),
+            loader.loadTestsFromTestCase(
+                ActiveDirectoryMultiPluginXMLAdapterTests),
+            loader.loadTestsFromTestCase(LDAPMultiPluginExportTests),
+            loader.loadTestsFromTestCase(ADMultiPluginExportTests),
+            loader.loadTestsFromTestCase(LDAPMultiPluginImportTests),
+            loader.loadTestsFromTestCase(ADMultiPluginImportTests),
         ))
 
 except ImportError:
